aboutsummaryrefslogtreecommitdiffstats
path: root/ajde/src
diff options
context:
space:
mode:
Diffstat (limited to 'ajde/src')
-rw-r--r--ajde/src/org/aspectj/ajde/OutputLocationManager.java8
-rw-r--r--ajde/src/org/aspectj/ajde/internal/CompilerAdapter.java5
-rw-r--r--ajde/src/org/aspectj/ajde/internal/OutputLocationAdapter.java8
3 files changed, 11 insertions, 10 deletions
diff --git a/ajde/src/org/aspectj/ajde/internal/CompilerAdapter.java b/ajde/src/org/aspectj/ajde/internal/CompilerAdapter.java
index 9afe186a7..1d079102c 100644
--- a/ajde/src/org/aspectj/ajde/internal/CompilerAdapter.java
+++ b/ajde/src/org/aspectj/ajde/internal/CompilerAdapter.java
@@ -578,9 +578,10 @@ public class CompilerAdapter {
}
// set compilation result destination manager if not set
+ OutputLocationManager outputLocationManager = properties.getOutputLocationManager();
if (config.getCompilationResultDestinationManager() == null &&
- properties.getOutputLocationManager() != null) {
- config.setCompilationResultDestinationManager(new OutputLocationAdapter(properties.getOutputLocationManager()));
+ outputLocationManager != null) {
+ config.setCompilationResultDestinationManager(new OutputLocationAdapter(outputLocationManager));
}
join(config.getSourceRoots(), properties.getSourceRoots());
diff --git a/ajde/src/org/aspectj/ajde/internal/OutputLocationAdapter.java b/ajde/src/org/aspectj/ajde/internal/OutputLocationAdapter.java
index 81c54b457..9ac479c8c 100644
--- a/ajde/src/org/aspectj/ajde/internal/OutputLocationAdapter.java
+++ b/ajde/src/org/aspectj/ajde/internal/OutputLocationAdapter.java
@@ -24,12 +24,12 @@ public class OutputLocationAdapter implements CompilationResultDestinationManage
this.locationManager = mgr;
}
- public File getOutputLocationForClass(String compilationUnitName) {
- return this.locationManager.getOutputLocationForClass(compilationUnitName);
+ public File getOutputLocationForClass(File compilationUnit) {
+ return this.locationManager.getOutputLocationForClass(compilationUnit);
}
- public File getOutputLocationForResource(String resourceName) {
- return this.locationManager.getOutputLocationForResource(resourceName);
+ public File getOutputLocationForResource(File resource) {
+ return this.locationManager.getOutputLocationForResource(resource);
}
}
diff --git a/ajde/src/org/aspectj/ajde/OutputLocationManager.java b/ajde/src/org/aspectj/ajde/OutputLocationManager.java
index 9a8c46d5f..3535722dc 100644
--- a/ajde/src/org/aspectj/ajde/OutputLocationManager.java
+++ b/ajde/src/org/aspectj/ajde/OutputLocationManager.java
@@ -27,21 +27,21 @@ public interface OutputLocationManager {
* this method returns "target/classes" the resulting class file will be written
* to "target/classes/a/b/C.class"
*
* @param compilationUnitName the fully-qualified name of the compilation unit that has been
* compiled
* @return a File object representing the root directory under which compilation results for this
* unit should be written
*/
- File getOutputLocationForClass(String compilationUnitName);
+ File getOutputLocationForClass(File compilationUnit);
/**
* When copying resources from source folders to output location, return the
* root directory under which the resource should be copied.
*
- * @param resourceName the fully-qualified name of the resource to be copied
+ * @param resource the resource to be copied
* @return a File object representing the root directory under which this resource
* should be copied
*/
- File getOutputLocationForResource(String resourceName);
+ File getOutputLocationForResource(File resource);
}
@@ -27,21 +27,21 @@ public interface OutputLocationManager {
* to "target/classes/a/b/C.class"
*
- * @param compilationUnitName the fully-qualified name of the compilation unit that has been
+ * @param compilationUnit the compilation unit that has been
* compiled
* @return a File object representing the root directory under which compilation results for this